@@ -1,6 +1,6 @@
+import sys
 import pytest
 
-
 def supported():
     import django.test.testcases
 
@@ -49,15 +49,21 @@ class LiveServer(object):
     def url(self):
         return 'http://%s:%s' % (self.thread.host, self.thread.port)
 
-    def __unicode__(self):
-        return self.url
+    if sys.version_info < (3, 0):
+        def __unicode__(self):
+            return self.url
+
+        def __add__(self, other):
+            return unicode(self) + other
+    else:
+        def __str__(self):
+            return self.url
+
+        def __add__(self, other):
+            return str(self) + other
 
     def __repr__(self):
-        return '<LiveServer listening at %s>' % unicode(self)
-
-    def __add__(self, other):
-        # Support string concatenation
-        return unicode(self) + other
+        return '<LiveServer listening at %s>' % self.url
 
 
 def parse_addr(specified_address):
@@ -73,7 +79,7 @@ def parse_addr(specified_address):
         host, port_ranges = specified_address.split(':')
         for port_range in port_ranges.split(','):
             # A port range can be of either form: '8000' or '8000-8010'.
-            extremes = map(int, port_range.split('-'))
+            extremes = list(map(int, port_range.split('-')))
             assert len(extremes) in [1, 2]
             if len(extremes) == 1:
                 # Port range of the form '8000'
