@@ -5,6 +5,7 @@ test database and provides some useful text fixtues.
 """
 
 import os
+import sys
 
 import pytest
 
@@ -70,7 +71,8 @@ def pytest_configure(config):
         from django.conf import settings
         try:
             settings.DATABASES
-        except ImportError, e:
+        except ImportError:
+            e = sys.exc_info()[1]
             raise pytest.UsageError(*e.args)
 
     # Register the marks
@@ -118,7 +120,7 @@ def _django_runner(request):
 def _django_cursor_wrapper(request):
     """The django cursor wrapper, internal to pytest-django
 
-    This will gobally disable all database access.  The object
+    This will globally disable all database access. The object
     returned has a .enable() and a .disable() method which can be used
     to temporarily enable database access.
     """
